require 'spec_helper'

describe 'ext_form_builder spec(bootstrap layout):' do
  before do
    ExtForm.setup do |e|
      e.layout = 'BootstrapLayout'
      e.default_wrapper = :ext_bootstrap
      e.default_layout = {
          layout: '1:1',
          spacing: '1',
          label_width: '2',
          max_width: '12'
      }
    end
  end

  let(:order_header) { FactoryGirl.create(:order_header) }

  let(:template) do
    template = ActionView::Base.new
    template.output_buffer = ""
    template
  end

  context 'no options' do
    subject do
      ExtForm::Builders::FormBuilderBase.new('OrderHeader', order_header, template, {}) do |f|
        f.input :order_number
      end
    end

    it 'initialize successfully' do
      subject.l.layout_config[:spacing].should eq('1')
      subject.l.layout_config[:label_width].should eq('2')
      subject.l.layout_config[:layout].should eq('1:1')
      subject.l.layout_config[:max_width].should eq('12')

      subject.l.layout.should eq([['2', '3'], ['2', '3']])
    end
  end

  context 'correct options' do
    subject do
      ExtForm::Builders::FormBuilderBase.new('OrderHeader', order_header, template,
                                             l: bs_correct_options) do |f|
        f.input :order_number
      end
    end

    it 'initialize successfully' do
      subject.l.layout_config[:spacing].should eq('0')
      subject.l.layout_config[:label_width].should eq('1')
      subject.l.layout_config[:layout].should eq('1:1:1')
      subject.l.layout_config[:max_width].should eq('12')

      subject.l.layout.should eq([['1', '3'], ['1', '3'], ['1', '3']])
    end
  end

  context 'error options' do
    subject do
      ExtForm::Builders::FormBuilderBase.new('OrderHeader', order_header, template,
                                             l: bs_error_options) do |f|
        f.input :order_number
      end
    end

    it 'initialize successfully' do
      subject.l.layout_config[:spacing].should eq('1')
      subject.l.layout_config[:label_width].should eq('2')
      subject.l.layout_config[:layout].should eq('1:1')
      subject.l.layout_config[:max_width].should eq('12')

      subject.l.layout.should eq([['2', '3'], ['2', '3']])

    end
  end
end