require 'spec_helper'
require 'action_view'

describe 'ext_form_builder spec(default layout):' do
  before do
    ExtForm.setup do |e|
      e.layout = 'DefaultLayout'
      e.default_wrapper = :ext
      e.default_layout = {
          layout: '1:1',
          spacing: '10',
          label_width: '15',
          max_width: '100',
          measure: '%'
      }
    end
  end

  let(:order_header) { FactoryGirl.create(:order_header) }

  let(:template) do
    template = ActionView::Base.new
    template.output_buffer = ""
    template
  end

  context 'no options' do
    subject do
      ExtForm::Builders::FormBuilderBase.new('OrderHeader', order_header, template, {}) do |f|
        f.input :order_number
      end
    end

    it 'initialize successfully' do
      subject.l.layout_config[:spacing].should eq('10')
      subject.l.layout_config[:label_width].should eq('15')
      subject.l.layout_config[:layout].should eq('1:1')
      subject.l.layout_config[:max_width].should eq('100')

      subject.l.layout.should eq([['15', '25.0'], ['15', '25.0']])
    end
  end

  context 'percentage layout options' do
    subject do
      ExtForm::Builders::FormBuilderBase.new('OrderHeader', order_header, template,
                                             l: percentage_options) do |f|
        f.input :order_number
      end
    end

    it 'initialize successfully' do
      subject.l.layout_config[:spacing].should eq('5')
      subject.l.layout_config[:label_width].should eq('5')
      subject.l.layout_config[:layout].should eq('1:1:1')
      subject.l.layout_config[:max_width].should eq('100')

      subject.l.layout.should eq([['5', '25.0'], ['5', '25.0'], ['5', '25.0']])
    end
  end

  context 'px layout options' do
    subject do
      ExtForm::Builders::FormBuilderBase.new('OrderHeader', order_header, template,
                                             l: px_options) do |f|
        f.input :order_number
      end
    end

    it 'initialize successfully' do
      subject.l.layout_config[:spacing].should eq('30')
      subject.l.layout_config[:label_width].should eq('160')
      subject.l.layout_config[:layout].should eq('1:1:1')
      subject.l.layout_config[:max_width].should eq('900')

      subject.l.layout.should eq([['160', '120.0'], ['160', '120.0'], ['160', '120.0']])

    end
  end

  context 'error options' do
    subject do
      ExtForm::Builders::FormBuilderBase.new('OrderHeader', order_header, template,
                                             l: error_options) do |f|
        f.input :order_number
      end
    end

    it 'initialize successfully' do
      subject.l.layout_config[:spacing].should eq('10')
      subject.l.layout_config[:label_width].should eq('15')
      subject.l.layout_config[:layout].should eq('1:1')
      subject.l.layout_config[:max_width].should eq('100')

      subject.l.layout.should eq([['15', '25.0'], ['15', '25.0']])

    end
  end
end

