require 'spec_helper'
require 'action_view'

describe 'form_helper_bs spec:' do

  before do
    ExtForm.setup do |e|
      e.layout = 'BootstrapLayout'
      e.default_wrapper = :ext_bootstrap
      e.default_layout = {
          layout: '1:1',
          spacing: '1',
          label_width: '2',
          max_width: '12'
      }
    end
  end

  let(:order_header) { FactoryGirl.create(:order_header) }

  context 'no options' do

    subject {
      helper.ext_form_for(order_header) do |f|
        f.input :order_number
      end
    }

    it 'ext_form_for should render all-inputs' do
      expect(subject).to match /<div class="left-spacing span1">/
      expect(subject).to match /<div class="all-inputs span10">/
      expect(subject).to match /<div class="right-spacing span1">/

      expect(subject).to match /<div class="span2"><label/
      expect(subject).to match /<div class="span3"><input class="span3/
    end

  end

  context 'correct options' do

    subject {
      helper.ext_form_for(order_header, l: bs_correct_options) do |f|
        f.input :order_number
      end
    }

    it 'ext_form_for should render all-inputs' do
      expect(subject).not_to match /<div class="left-spacing span0">/
      expect(subject).to match /<div class="all-inputs span12">/
      expect(subject).not_to match /<div class="right-spacing span0">/

      expect(subject).to match /<div class="span1"><label/
      expect(subject).to match /<div class="span3"><input class="span3/
    end

  end

  context 'error options' do

    subject {
      helper.ext_form_for(order_header, l: bs_error_options) do |f|
        f.input :order_number
      end
    }

    it 'ext_form_for should render all-inputs' do
      expect(subject).to match /<div class="left-spacing span1">/
      expect(subject).to match /<div class="all-inputs span10">/
      expect(subject).to match /<div class="right-spacing span1">/

      expect(subject).to match /<div class="span2"><label/
      expect(subject).to match /<div class="span3"><input class="span3/
    end

  end

  context 'swap layout' do

    subject {
      helper.ext_form_for(order_header, l: error_options) do |f|
        [f.input(:order_number),
         f.input(:customer_name),

         f.inputs('1') do |ff|

           [ff.input(:customer_name),
            ff.input(:customer_name)].join.html_safe
         end,

         f.input(:order_number),
         f.input(:customer_name)].join.html_safe
      end
    }

    it 'ext_form_for and swap_layout should render all-inputs correctly' do
      expect(subject).to match /<div class="span3"><input class="span3/
      expect(subject).to match /<div class="span8"><input class="span8/
    end
  end

end