require 'spec_helper'
require 'action_view'

describe 'form_helper spec:' do

  before do
    ExtForm.setup do |e|
      e.layout = 'DefaultLayout'
      e.default_wrapper = :ext
      e.default_layout = {
          layout: '1:1',
          spacing: '10',
          label_width: '15',
          max_width: '100',
          measure: '%'
      }
    end
  end

  let(:order_header) { FactoryGirl.create(:order_header) }

  context 'no options' do

    subject {
      helper.ext_form_for(order_header) do |f|
        f.input :order_number
      end
    }

    it 'ext_form_for should render all-inputs' do
      expect(subject).to match /<div class="all-inputs" style="padding-left: 10%; padding-right: 10%; width: 80\.0%;">/
      expect(subject).to match /<div style="width: 15%; float: left;"><label/
      expect(subject).to match /<div style="width: 25\.0%; float: left;"><input class="input-with-layout/
    end

  end

  context 'percentage options' do

    subject {
      helper.ext_form_for(order_header, l: percentage_options) do |f|
        f.input :order_number
      end
    }

    it 'ext_form_for should render all-inputs' do
      expect(subject).to match /<div class="all-inputs" style="padding-left: 5%; padding-right: 5%; width: 90\.0%;">/
      expect(subject).to match /<div style="width: 5%; float: left;"><label/
      expect(subject).to match /<div style="width: 25\.0%; float: left;"><input class="input-with-layout/
    end

  end

  context 'px options' do

    subject {
      helper.ext_form_for(order_header, l: px_options) do |f|
        f.input :order_number
      end
    }

    it 'ext_form_for should render all-inputs' do
      expect(subject).to match /<div class="all-inputs" style="padding-left: 30px; padding-right: 30px; width: 840\.0px;">/
      expect(subject).to match /<div style="width: 160px; float: left;"><label/
      expect(subject).to match /<div style="width: 120\.0px; float: left;"><input class="input-with-layout/
    end

  end

  context 'error options' do

    subject {
      helper.ext_form_for(order_header, l: error_options) do |f|
        f.input :order_number
      end
    }

    it 'ext_form_for should render all-inputs' do
      expect(subject).to match /<div class="all-inputs" style="padding-left: 10%; padding-right: 10%; width: 80\.0%;">/
      expect(subject).to match /<div style="width: 15%; float: left;"><label/
      expect(subject).to match /<div style="width: 25\.0%; float: left;"><input class="input-with-layout/
    end

  end

  context 'swap layout' do

    subject {
      helper.ext_form_for(order_header, l: error_options) do |f|
        [f.input(:order_number),
         f.input(:customer_name),

         f.inputs('1') do |ff|

           [ff.input(:customer_name),
            ff.input(:customer_name)].join.html_safe
         end,

         f.input(:order_number),
         f.input(:customer_name)].join.html_safe
      end
    }

    it 'ext_form_for and swap_layout should render all-inputs correctly' do
      expect(subject).to match /<div style="width: 25\.0%; float: left;"><input class="input-with-layout/
      expect(subject).to match /<div style="width: 65\.0%; float: left;"><input class="input-with-layout/
    end
  end
end